#!/usr/bin/perl -w

# Simple whitelist filter for Safari cookies: removes all 
# those cookies where the domain name is not in the whitelist.
#
# Edit the @valid_domains array before you execute this; and 
# Safari should obviously be closed.
#
# No warranties. Backup first.
#
# Martin Dittus, http://dekstop.de/cookiefilter/
# Last change: 2005-07-29

=pod

TODO
- params: 
	-v verbose output (shows "Keeping cookie x")
	-s silent (no output)
	-t test (prints output, but doesn't change the cookie file)
=cut

use strict;
use warnings;

use Mac::PropertyList;

# ===============
# config
# ===============

my @valid_domains = (
	"flickr.com", "musikcube.com", "del.icio.us"
);

my $filename = glob("~/Library/Cookies/Cookies.plist");
my $in = Mac::PropertyList::parse_plist_file( $filename );
my $out = Mac::PropertyList::array->new();
my $count = 0;


# ===============
# subs
# ===============

sub get_timestamp_string() {
	(my $second, my $minute, my $hour, my $day, my $month, my $year, my $weekday, my $dayofyear, my $isDST) = localtime(time); 
	$month++;
	if ($month < 10) { 
	        $month = "0".$month; 
	} 
	if ($day < 10) { 
	        $day = "0".$day; 
	}
	$year += 1900;
	if ($hour < 10) { 
	        $hour = "0".$hour; 
	}
	if ($minute < 10) { 
	        $minute = "0".$minute; 
	}
	if ($second < 10) { 
	        $second = "0".$second; 
	}
	return "$year-$month-$day $hour:$minute:$second";
}

# returns $string1 if ($value == 1), and $string2 in all other cases
# parameters: $value, $string1, $string2
# returns: $string1 or $string2
sub plural_form($$$) {
	my $value = shift;
	my $s1 = shift;
	my $s2 = shift;
	if ($value == 1) {
		return $s1;
	}
	else {
		return $s2;
	}
}

# ===============
# main
# ===============

#print get_timestamp_string() ." CookieFilter: Checking shared cookie storage...\n";

foreach my $entry (@{$in}) {
	my %cookie = %{$entry};
	my $domain = $cookie{"Domain"}->value();
	my $match = 0;
	foreach my $item (@valid_domains) {
		$match = 1 if ($domain =~ m/$item/i);
		last if ($match == 1);
	}
	if ($match == 1) {
		push @{$out}, $entry;
		#print get_timestamp_string() ." CookieFilter: Keeping cookie for $domain\n";		
	}
	else {	
		print get_timestamp_string() ." CookieFilter: Removing cookie for $domain\n";
		$count++;
	}
}

open(FILE,"> $filename" ) or die $!;
print FILE Mac::PropertyList::plist_as_string($out);
close(FILE);

#print get_timestamp_string() ." CookieFilter: Removed $count ". plural_form($count, "cookie", "cookies") .".\n";
